/*
* @license Apache-2.0
*
* Copyright (c) 2021 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

// TypeScript Version: 2.0

/// <reference types="@stdlib/types"/>

import { ArrayLike } from '@stdlib/types/array';
import { Collection } from '@stdlib/types/object';

/**
* Reduces the number of dimensions by one of a two-dimensional nested array by applying a function against an accumulator and each element along the innermost dimension and returning the accumulation results as a one-dimensional array.
*
* ## Notes
*
* -   The applied function is provided the following arguments:
*
*     -   **accumulator**: accumulated value.
*     -   **value**: array element.
*     -   **i**: index of the first dimension.
*     -   **j**: index of the second dimension.
*     -   **arr**: input array.
*
* @param arr - array of arrays
* @param initial - initial values
* @param reducer - function to apply
* @param thisArg - input function context
* @throws the second argument must have a length equal to the size of the outermost input array dimension
* @returns accumulation results
*
* @example
* var naryFunction = require( `@stdlib/utils/nary-function` );
* var add = require( `@stdlib/math/base/ops/add` );
*
* var arr = [
*     [ 1, 2, 3 ],
*     [ 4, 5, 6 ]
* ];
*
* var out = reduce2d( arr, [ 0, 0 ], naryFunction( add, 2 ) );
* // returns [ 6, 15 ]
*/
declare function reduce2d( arr: ArrayLike<Collection>, initial: ArrayLike<any>, reducer: Function, thisArg?: any ): Array<any>; // tslint-disable-line max-line-length


// EXPORTS //

export = reduce2d;
